@@ -163,7 +163,7 @@ def dumps(doc: Document, fragment_newlines: bool = True) -> str:
         if "\n" in e.text and fragment_newlines:
             line = get_fragmented_line(e)
         else:
-            line = f"{e.id}\t{e.type}"
+            line = f"{e.id}\t{e.type} {e.start} {e.end}\t{e.text}"
         lines.append(line)
     for r in doc.relations:
         # remove relations with missing arg1 or arg2
